@@ -3,7 +3,7 @@ setRefClass("RzSettings",
   fields = c("RzPath", "path", "theme", "theme.this", "globalFont", "variableViewFont", "monospaceFont", "monospaceFontFamily",
     "plotFont", "plotFontFamily", "useDataSetObject", "themesFolder",
     "useEmbededDevice", "embededDeviceOn", "runPlot", "codebookOff", "popupOff",
-    "plotViewEnabled", "variableEditorViewEnabled", "psFont", "pdfFont"),
+    "plotViewEnabled", "analysisViewEnabled", "psFont", "pdfFont"),
   methods = list(
     load = function(){
       path <<- "~/.Rz"
@@ -79,7 +79,7 @@ setRefClass("RzSettings",
       }
       
       plotViewEnabled <<- FALSE
-      variableEditorViewEnabled <<- FALSE
+      analysisViewEnabled <<- FALSE
     },
     
     runDialog = function(win){
@@ -110,8 +110,8 @@ setRefClass("RzSettings",
       themes.hbox$packStart(themes.label, expand=FALSE)
       themes.hbox$packStart(themesCombo)
       
-      checkButtonUseDataSet <- gtkCheckButtonNewWithLabel(gettext("Sync as data.set object"))
-      checkButtonUseDataSet$setActive(useDataSetObject)
+#      checkButtonUseDataSet <- gtkCheckButtonNewWithLabel(gettext("Sync as data.set object"))
+#      checkButtonUseDataSet$setActive(useDataSetObject)
       checkButtonUseEmbededDevice <- gtkCheckButtonNewWithLabel(gettext("Use embeded graphics divice (requires cairoDevice package)"))
       checkButtonUseEmbededDevice$setActive(useEmbededDevice)
       checkButtonRunPlot <- gtkCheckButtonNewWithLabel(gettext("Plot when a index cell is double-clicked"))
@@ -125,7 +125,7 @@ setRefClass("RzSettings",
       general.tab["border-width"] <- 2
       general.tab$packStart(themes.folder.hbox, expand=FALSE)
       general.tab$packStart(themes.hbox, expand=FALSE)
-      general.tab$packStart(checkButtonUseDataSet, expand=FALSE)
+#      general.tab$packStart(checkButtonUseDataSet, expand=FALSE)
       general.tab$packStart(checkButtonUseEmbededDevice, expand=FALSE)
       general.tab$packStart(checkButtonRunPlot, expand=FALSE)
       general.tab$packStart(checkButtonCodebookOff, expand=FALSE)
@@ -182,7 +182,7 @@ setRefClass("RzSettings",
           plotFontFamily   <<- pangoFontDescriptionFromString(plotFont)$getFamily()
           psFont           <<- localize(psFontCombo$getActiveText())
           pdfFont          <<- localize(pdfFontCombo$getActiveText())
-          useDataSetObject <<- checkButtonUseDataSet$getActive()
+#          useDataSetObject <<- checkButtonUseDataSet$getActive()
           useEmbededDevice <<- checkButtonUseEmbededDevice$getActive()
           runPlot          <<- checkButtonRunPlot$getActive()
           codebookOff      <<- checkButtonCodebookOff$getActive()
@@ -199,7 +199,7 @@ setRefClass("RzSettings",
             plotFont         = plotFont,
             psFont           = psFont,
             pdfFont          = pdfFont,
-            useDataSetObject = useDataSetObject,
+#            useDataSetObject = useDataSetObject,
             useEmbededDevice = useEmbededDevice,
             runPlot          = runPlot,
             codebookOff      = codebookOff,
@@ -220,5 +220,5 @@ setRefClass("RzSettings",
 )
 settings$accessors(c("RzPath", "themesFolder", "globalFont", "variableViewFont", "monospaceFont", "monospaceFontFamily", "plotFont", "plotFontFamily",
                      "useDataSetObject","useEmbededDevice", "embededDeviceOn", "runPlot", "codebookOff", "popupOff",
-                     "plotViewEnabled", "variableEditorViewEnabled", "psFont", "pdfFont"))
+                     "plotViewEnabled", "analysisViewEnabled", "psFont", "pdfFont"))
 
